.. _enhanced_products:

Enhanced Pipeline Products code API
-------------------------------------

.. automodule:: drizzlepac.alignimages
.. autofunction:: drizzlepac.alignimages.perform_align
.. autofunction:: drizzlepac.alignimages.generate_source_catalogs


.. automodule:: drizzlepac.hlautils.astrometric_utils
.. autofunction:: drizzlepac.hlautils.astrometric_utils.create_astrometric_catalog
.. autofunction:: drizzlepac.hlautils.astrometric_utils.get_catalog
.. autofunction:: drizzlepac.hlautils.astrometric_utils.find_gsc_offset
.. autofunction:: drizzlepac.hlautils.astrometric_utils.extract_sources
.. autofunction:: drizzlepac.hlautils.astrometric_utils.classify_sources
.. autofunction:: drizzlepac.hlautils.astrometric_utils.generate_source_catalog
.. autofunction:: drizzlepac.hlautils.astrometric_utils.generate_sky_catalog
.. autofunction:: drizzlepac.hlautils.astrometric_utils.compute_photometry
.. autofunction:: drizzlepac.hlautils.astrometric_utils.filter_catalog
.. autofunction:: drizzlepac.hlautils.astrometric_utils.build_self_reference
.. autofunction:: drizzlepac.hlautils.astrometric_utils.within_footprint
.. autofunction:: drizzlepac.hlautils.astrometric_utils.find_hist2d_offset
.. autofunction:: drizzlepac.hlautils.astrometric_utils.build_wcscat

.. automodule:: drizzlepac.hlautils.astroquery_utils
.. autofunction:: drizzlepac.hlautils.astroquery_utils.retrieve_observation

.. automodule:: drizzlepac.hlautils.testutils
.. autofunction:: drizzlepac.hlautils.testutils.compare_wcs_alignment
